@@ -1,20 +1,27 @@
 'use strict'
 
-const http = require('http')
-const os = require('os')
-const path = require('path')
-const { table } = require('table')
-const { Writable } = require('stream')
-const { WritableStream } = require('stream/web')
-const { isMainThread } = require('worker_threads')
+const http = require('node:http')
+const os = require('node:os')
+const path = require('node:path')
+const { Writable } = require('node:stream')
+const { isMainThread } = require('node:worker_threads')
 
 const { Pool, Client, fetch, Agent, setGlobalDispatcher } = require('..')
 
+const { makeParallelRequests, printResults } = require('./_util')
+
+let nodeFetch
+const axios = require('axios')
+let superagent
+let got
+
+const { promisify } = require('node:util')
+const request = promisify(require('request'))
+
 const iterations = (parseInt(process.env.SAMPLES, 10) || 10) + 1
-const errorThreshold = parseInt(process.env.ERROR_TRESHOLD, 10) || 3
+const errorThreshold = parseInt(process.env.ERROR_THRESHOLD, 10) || 3
 const connections = parseInt(process.env.CONNECTIONS, 10) || 50
 const pipelining = parseInt(process.env.PIPELINING, 10) || 10
-const parallelRequests = parseInt(process.env.PARALLEL, 10) || 100
 const headersTimeout = parseInt(process.env.HEADERS_TIMEOUT, 10) || 0
 const bodyTimeout = parseInt(process.env.BODY_TIMEOUT, 10) || 0
 const dest = {}
@@ -27,22 +34,16 @@ if (process.env.PORT) {
   dest.socketPath = path.join(os.tmpdir(), 'undici.sock')
 }
 
+/** @type {http.RequestOptions} */
 const httpBaseOptions = {
   protocol: 'http:',
   hostname: 'localhost',
   method: 'GET',
   path: '/',
-  query: {
-    frappucino: 'muffin',
-    goat: 'scone',
-    pond: 'moose',
-    foo: ['bar', 'baz', 'bal'],
-    bool: true,
-    numberKey: 256
-  },
   ...dest
 }
 
+/** @type {http.RequestOptions} */
 const httpNoKeepAliveOptions = {
   ...httpBaseOptions,
   agent: new http.Agent({
@@ -51,6 +52,7 @@ const httpNoKeepAliveOptions = {
   })
 }
 
+/** @type {http.RequestOptions} */
 const httpKeepAliveOptions = {
   ...httpBaseOptions,
   agent: new http.Agent({
@@ -59,9 +61,36 @@ const httpKeepAliveOptions = {
   })
 }
 
+const axiosAgent = new http.Agent({
+  keepAlive: true,
+  maxSockets: connections
+})
+
+const fetchAgent = new http.Agent({
+  keepAlive: true,
+  maxSockets: connections
+})
+
+const gotAgent = new http.Agent({
+  keepAlive: true,
+  maxSockets: connections
+})
+
+const requestAgent = new http.Agent({
+  keepAlive: true,
+  maxSockets: connections
+})
+
+const superagentAgent = new http.Agent({
+  keepAlive: true,
+  maxSockets: connections
+})
+
 const undiciOptions = {
   path: '/',
   method: 'GET',
+  blocking: false,
+  reset: false,
   headersTimeout,
   bodyTimeout
 }
@@ -109,75 +138,6 @@ class SimpleRequest {
   }
 }
 
-function makeParallelRequests (cb) {
-  return Promise.all(Array.from(Array(parallelRequests)).map(() => new Promise(cb)))
-}
-
-function printResults (results) {
-  // Sort results by least performant first, then compare relative performances and also printing padding
-  let last
-
-  const rows = Object.entries(results)
-    // If any failed, put on the top of the list, otherwise order by mean, ascending
-    .sort((a, b) => (!a[1].success ? -1 : b[1].mean - a[1].mean))
-    .map(([name, result]) => {
-      if (!result.success) {
-        return [name, result.size, 'Errored', 'N/A', 'N/A']
-      }
-
-      // Calculate throughput and relative performance
-      const { size, mean, standardError } = result
-      const relative = last !== 0 ? (last / mean - 1) * 100 : 0
-
-      // Save the slowest for relative comparison
-      if (typeof last === 'undefined') {
-        last = mean
-      }
-
-      return [
-        name,
-        size,
-        `${((connections * 1e9) / mean).toFixed(2)} req/sec`,
-        `± ${((standardError / mean) * 100).toFixed(2)} %`,
-        relative > 0 ? `+ ${relative.toFixed(2)} %` : '-'
-      ]
-    })
-
-  console.log(results)
-
-  // Add the header row
-  rows.unshift(['Tests', 'Samples', 'Result', 'Tolerance', 'Difference with slowest'])
-
-  return table(rows, {
-    columns: {
-      0: {
-        alignment: 'left'
-      },
-      1: {
-        alignment: 'right'
-      },
-      2: {
-        alignment: 'right'
-      },
-      3: {
-        alignment: 'right'
-      },
-      4: {
-        alignment: 'right'
-      }
-    },
-    drawHorizontalLine: (index, size) => index > 0 && index < size,
-    border: {
-      bodyLeft: '│',
-      bodyRight: '│',
-      bodyJoin: '│',
-      joinLeft: '|',
-      joinRight: '|',
-      joinJoin: '|'
-    }
-  })
-}
-
 const experiments = {
   'http - no keepalive' () {
     return makeParallelRequests(resolve => {
@@ -212,8 +172,8 @@ const experiments = {
   'undici - pipeline' () {
     return makeParallelRequests(resolve => {
       dispatcher
-        .pipeline(undiciOptions, data => {
-          return data.body
+        .pipeline(undiciOptions, ({ body }) => {
+          return body
         })
         .end()
         .pipe(
@@ -270,10 +230,92 @@ if (process.env.PORT) {
       }).catch(console.log)
     })
   }
+
+  experiments['node-fetch'] = () => {
+    return makeParallelRequests(resolve => {
+      nodeFetch(dest.url, { agent: fetchAgent }).then(res => {
+        res.body.pipe(new Writable({
+          write (chunk, encoding, callback) {
+            callback()
+          }
+        })).on('finish', resolve)
+      }).catch(console.log)
+    })
+  }
+
+  const axiosOptions = {
+    url: dest.url,
+    method: 'GET',
+    responseType: 'stream',
+    httpAgent: axiosAgent
+  }
+  experiments.axios = () => {
+    return makeParallelRequests(resolve => {
+      axios.request(axiosOptions).then(res => {
+        res.data.pipe(new Writable({
+          write (chunk, encoding, callback) {
+            callback()
+          }
+        })).on('finish', resolve)
+      }).catch(console.log)
+    })
+  }
+
+  const gotOptions = {
+    url: dest.url,
+    method: 'GET',
+    agent: {
+      http: gotAgent
+    },
+    // avoid body processing
+    isStream: true
+  }
+  experiments.got = () => {
+    return makeParallelRequests(resolve => {
+      got(gotOptions).pipe(new Writable({
+        write (chunk, encoding, callback) {
+          callback()
+        }
+      })).on('finish', resolve)
+    })
+  }
+
+  const requestOptions = {
+    url: dest.url,
+    method: 'GET',
+    agent: requestAgent,
+    // avoid body toString
+    encoding: null
+  }
+  experiments.request = () => {
+    return makeParallelRequests(resolve => {
+      request(requestOptions).then(() => {
+        // already body consumed
+        resolve()
+      }).catch(console.log)
+    })
+  }
+
+  experiments.superagent = () => {
+    return makeParallelRequests(resolve => {
+      superagent.get(dest.url).pipe(new Writable({
+        write (chunk, encoding, callback) {
+          callback()
+        }
+      })).on('finish', resolve)
+    })
+  }
 }
 
 async function main () {
   const { cronometro } = await import('cronometro')
+  const _nodeFetch = await import('node-fetch')
+  nodeFetch = _nodeFetch.default
+  const _got = await import('got')
+  got = _got.default
+  const _superagent = await import('superagent')
+  // https://github.com/ladjs/superagent/issues/1540#issue-561464561
+  superagent = _superagent.agent().use((req) => req.agent(superagentAgent))
 
   cronometro(
     experiments,
@@ -287,7 +329,7 @@ async function main () {
         throw err
       }
 
-      console.log(printResults(results))
+      printResults(results)
       dispatcher.destroy()
     }
   )
