@@ -1,7 +1,7 @@
 'use strict'
 
-const os = require('os')
-const path = require('path')
+const os = require('node:os')
+const path = require('node:path')
 const waitOn = require('wait-on')
 
 const socketPath = path.join(os.tmpdir(), 'undici.sock')
