@@ -2,17 +2,20 @@
 
 'use strict'
 
-const { test } = require('tap')
-const { createServer } = require('http')
-const { ReadableStream } = require('stream/web')
-const { Blob } = require('buffer')
-const { fetch, Response, Request, FormData, File } = require('../..')
+const { test } = require('node:test')
+const assert = require('node:assert')
+const { tspl } = require('@matteo.collina/tspl')
+const { createServer } = require('node:http')
+const { Blob, File } = require('node:buffer')
+const { fetch, Response, Request, FormData } = require('../..')
 const { Client, setGlobalDispatcher, Agent } = require('../..')
 const nodeFetch = require('../../index-fetch')
-const { once } = require('events')
-const { gzipSync } = require('zlib')
-const { promisify } = require('util')
-const { randomFillSync, createHash } = require('crypto')
+const { once } = require('node:events')
+const { gzipSync } = require('node:zlib')
+const { promisify } = require('node:util')
+const { randomFillSync, createHash } = require('node:crypto')
+
+const { closeServerAsPromise } = require('../utils/node-http')
 
 setGlobalDispatcher(new Agent({
   keepAliveTimeout: 1,
@@ -20,86 +23,90 @@ setGlobalDispatcher(new Agent({
 }))
 
 test('function signature', (t) => {
-  t.plan(2)
+  const { strictEqual } = tspl(t, { plan: 2 })
 
-  t.equal(fetch.name, 'fetch')
-  t.equal(fetch.length, 1)
+  strictEqual(fetch.name, 'fetch')
+  strictEqual(fetch.length, 1)
 })
 
 test('args validation', async (t) => {
-  t.plan(2)
+  const { rejects } = tspl(t, { plan: 2 })
 
-  await t.rejects(fetch(), TypeError)
-  await t.rejects(fetch('ftp://unsupported'), TypeError)
+  await rejects(fetch(), TypeError)
+  await rejects(fetch('ftp://unsupported'), TypeError)
 })
 
-test('request json', (t) => {
-  t.plan(1)
+test('request json', (t, done) => {
+  const { deepStrictEqual } = tspl(t, { plan: 1 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const body = await fetch(`http://localhost:${server.address().port}`)
-    t.strictSame(obj, await body.json())
+    deepStrictEqual(obj, await body.json())
+    done()
   })
 })
 
-test('request text', (t) => {
-  t.plan(1)
+test('request text', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const body = await fetch(`http://localhost:${server.address().port}`)
-    t.strictSame(JSON.stringify(obj), await body.text())
+    strictEqual(JSON.stringify(obj), await body.text())
+    done()
   })
 })
 
-test('request arrayBuffer', (t) => {
-  t.plan(1)
+test('request arrayBuffer', (t, done) => {
+  const { deepStrictEqual } = tspl(t, { plan: 1 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const body = await fetch(`http://localhost:${server.address().port}`)
-    t.strictSame(Buffer.from(JSON.stringify(obj)), Buffer.from(await body.arrayBuffer()))
+    deepStrictEqual(Buffer.from(JSON.stringify(obj)), Buffer.from(await body.arrayBuffer()))
+    done()
   })
 })
 
-test('should set type of blob object to the value of the `Content-Type` header from response', (t) => {
-  t.plan(1)
+test('should set type of blob object to the value of the `Content-Type` header from response', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.setHeader('Content-Type', 'application/json')
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const response = await fetch(`http://localhost:${server.address().port}`)
-    t.equal('application/json', (await response.blob()).type)
+    strictEqual('application/json', (await response.blob()).type)
+    done()
   })
 })
 
-test('pre aborted with readable request body', (t) => {
-  t.plan(2)
+test('pre aborted with readable request body', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 2 })
 
   const server = createServer((req, res) => {
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const ac = new AbortController()
@@ -109,33 +116,33 @@ test('pre aborted with readable request body', (t) => {
       method: 'POST',
       body: new ReadableStream({
         async cancel (reason) {
-          t.equal(reason.name, 'AbortError')
+          strictEqual(reason.name, 'AbortError')
         }
       }),
       duplex: 'half'
     }).catch(err => {
-      t.equal(err.name, 'AbortError')
-    })
+      strictEqual(err.name, 'AbortError')
+    }).finally(done)
   })
 })
 
-test('pre aborted with closed readable request body', (t) => {
-  t.plan(2)
+test('pre aborted with closed readable request body', (t, done) => {
+  const { ok, strictEqual } = tspl(t, { plan: 2 })
 
   const server = createServer((req, res) => {
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const ac = new AbortController()
     ac.abort()
     const body = new ReadableStream({
       async start (c) {
-        t.pass()
+        ok(true)
         c.close()
       },
       async cancel (reason) {
-        t.fail()
+        assert.fail()
       }
     })
     queueMicrotask(() => {
@@ -145,32 +152,34 @@ test('pre aborted with closed readable request body', (t) => {
         body,
         duplex: 'half'
       }).catch(err => {
-        t.equal(err.name, 'AbortError')
-      })
+        strictEqual(err.name, 'AbortError')
+      }).finally(done)
     })
   })
 })
 
-test('unsupported formData 1', (t) => {
-  t.plan(1)
+test('unsupported formData 1', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const server = createServer((req, res) => {
     res.setHeader('content-type', 'asdasdsad')
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, () => {
     fetch(`http://localhost:${server.address().port}`)
       .then(res => res.formData())
       .catch(err => {
-        t.equal(err.name, 'TypeError')
+        strictEqual(err.name, 'TypeError')
       })
+      .finally(done)
   })
 })
 
 test('multipart formdata not base64', async (t) => {
-  t.plan(2)
+  const { strictEqual } = tspl(t, { plan: 2 })
+
   // Construct example form data, with text and blob fields
   const formData = new FormData()
   formData.append('field1', 'value1')
@@ -186,25 +195,34 @@ test('multipart formdata not base64', async (t) => {
     res.write(formRaw)
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   const listen = promisify(server.listen.bind(server))
   await listen(0)
 
   const res = await fetch(`http://localhost:${server.address().port}`)
   const form = await res.formData()
-  t.equal(form.get('field1'), 'value1')
+  strictEqual(form.get('field1'), 'value1')
 
   const text = await form.get('field2').text()
-  t.equal(text, 'example\ntext file')
+  strictEqual(text, 'example\ntext file')
 })
 
-test('multipart formdata base64', (t) => {
-  t.plan(1)
+test('multipart formdata base64', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   // Example form data with base64 encoding
   const data = randomFillSync(Buffer.alloc(256))
-  const formRaw = `------formdata-undici-0.5786922755719377\r\nContent-Disposition: form-data; name="file"; filename="test.txt"\r\nContent-Type: application/octet-stream\r\nContent-Transfer-Encoding: base64\r\n\r\n${data.toString('base64')}\r\n------formdata-undici-0.5786922755719377--`
+  const formRaw =
+    '------formdata-undici-0.5786922755719377\r\n' +
+    'Content-Disposition: form-data; name="file"; filename="test.txt"\r\n' +
+    'Content-Type: application/octet-stream\r\n' +
+    'Content-Transfer-Encoding: base64\r\n' +
+    '\r\n' +
+    data.toString('base64') +
+    '\r\n' +
+    '------formdata-undici-0.5786922755719377--'
+
   const server = createServer(async (req, res) => {
     res.setHeader('content-type', 'multipart/form-data; boundary=----formdata-undici-0.5786922755719377')
 
@@ -214,7 +232,7 @@ test('multipart formdata base64', (t) => {
     }
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, () => {
     fetch(`http://localhost:${server.address().port}`)
@@ -222,13 +240,14 @@ test('multipart formdata base64', (t) => {
       .then(form => form.get('file').arrayBuffer())
       .then(buffer => createHash('sha256').update(Buffer.from(buffer)).digest('base64'))
       .then(digest => {
-        t.equal(createHash('sha256').update(data).digest('base64'), digest)
+        strictEqual(createHash('sha256').update(data).digest('base64'), digest)
       })
+      .finally(done)
   })
 })
 
 test('multipart fromdata non-ascii filed names', async (t) => {
-  t.plan(1)
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const request = new Request('http://localhost', {
     method: 'POST',
@@ -244,11 +263,11 @@ test('multipart fromdata non-ascii filed names', async (t) => {
   })
 
   const form = await request.formData()
-  t.equal(form.get('fiŝo'), 'value1')
+  strictEqual(form.get('fiŝo'), 'value1')
 })
 
 test('busboy emit error', async (t) => {
-  t.plan(1)
+  const { rejects } = tspl(t, { plan: 1 })
   const formData = new FormData()
   formData.append('field1', 'value1')
 
@@ -260,109 +279,125 @@ test('busboy emit error', async (t) => {
     res.write(formRaw)
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   const listen = promisify(server.listen.bind(server))
   await listen(0)
 
   const res = await fetch(`http://localhost:${server.address().port}`)
-  await t.rejects(res.formData(), 'Unexpected end of multipart data')
+  await rejects(res.formData(), 'Unexpected end of multipart data')
 })
 
-test('urlencoded formData', (t) => {
-  t.plan(2)
+// https://github.com/nodejs/undici/issues/2244
+test('parsing formData preserve full path on files', async (t) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
+  const formData = new FormData()
+  formData.append('field1', new File(['foo'], 'a/b/c/foo.txt'))
+
+  const tempRes = new Response(formData)
+  const form = await tempRes.formData()
+
+  strictEqual(form.get('field1').name, 'a/b/c/foo.txt')
+})
+
+test('urlencoded formData', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 2 })
 
   const server = createServer((req, res) => {
     res.setHeader('content-type', 'application/x-www-form-urlencoded')
     res.end('field1=value1&field2=value2')
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, () => {
     fetch(`http://localhost:${server.address().port}`)
       .then(res => res.formData())
       .then(formData => {
-        t.equal(formData.get('field1'), 'value1')
-        t.equal(formData.get('field2'), 'value2')
+        strictEqual(formData.get('field1'), 'value1')
+        strictEqual(formData.get('field2'), 'value2')
       })
+      .finally(done)
   })
 })
 
-test('text with BOM', (t) => {
-  t.plan(1)
+test('text with BOM', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const server = createServer((req, res) => {
     res.setHeader('content-type', 'application/x-www-form-urlencoded')
     res.end('\uFEFFtest=\uFEFF')
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, () => {
     fetch(`http://localhost:${server.address().port}`)
       .then(res => res.text())
       .then(text => {
-        t.equal(text, 'test=\uFEFF')
+        strictEqual(text, 'test=\uFEFF')
       })
+      .finally(done)
   })
 })
 
-test('formData with BOM', (t) => {
-  t.plan(1)
+test('formData with BOM', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const server = createServer((req, res) => {
     res.setHeader('content-type', 'application/x-www-form-urlencoded')
     res.end('\uFEFFtest=\uFEFF')
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, () => {
     fetch(`http://localhost:${server.address().port}`)
       .then(res => res.formData())
       .then(formData => {
-        t.equal(formData.get('\uFEFFtest'), '\uFEFF')
+        strictEqual(formData.get('\uFEFFtest'), '\uFEFF')
       })
+      .finally(done)
   })
 })
 
-test('locked blob body', (t) => {
-  t.plan(1)
+test('locked blob body', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const server = createServer((req, res) => {
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`)
     const reader = res.body.getReader()
     res.blob().catch(err => {
-      t.equal(err.message, 'Body is unusable')
+      strictEqual(err.message, 'Body is unusable: Body has already been read')
       reader.cancel()
-    })
+    }).finally(done)
   })
 })
 
-test('disturbed blob body', (t) => {
-  t.plan(2)
+test('disturbed blob body', (t, done) => {
+  const { ok, strictEqual } = tspl(t, { plan: 2 })
 
   const server = createServer((req, res) => {
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`)
-    res.blob().then(() => {
-      t.pass(2)
+    await res.blob().then(() => {
+      ok(true)
     })
-    res.blob().catch(err => {
-      t.equal(err.message, 'Body is unusable')
+    await res.blob().catch(err => {
+      strictEqual(err.message, 'Body is unusable: Body has already been read')
     })
+    done()
   })
 })
 
-test('redirect with body', (t) => {
-  t.plan(3)
+test('redirect with body', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 3 })
 
   let count = 0
   const server = createServer(async (req, res) => {
@@ -370,7 +405,7 @@ test('redirect with body', (t) => {
     for await (const chunk of req) {
       body += chunk
     }
-    t.equal(body, 'asd')
+    strictEqual(body, 'asd')
     if (count++ === 0) {
       res.setHeader('location', 'asd')
       res.statusCode = 302
@@ -379,19 +414,20 @@ test('redirect with body', (t) => {
       res.end(String(count))
     }
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`, {
       method: 'PUT',
       body: 'asd'
     })
-    t.equal(await res.text(), '2')
+    strictEqual(await res.text(), '2')
+    done()
   })
 })
 
-test('redirect with stream', (t) => {
-  t.plan(3)
+test('redirect with stream', (t, done) => {
+  const { strictEqual } = tspl(t, { plan: 3 })
 
   const location = '/asd'
   const body = 'hello!'
@@ -406,20 +442,21 @@ test('redirect with stream', (t) => {
       }
     }, 50)
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`, {
       redirect: 'manual'
     })
-    t.equal(res.status, 302)
-    t.equal(res.headers.get('location'), location)
-    t.equal(await res.text(), body)
+    strictEqual(res.status, 302)
+    strictEqual(res.headers.get('location'), location)
+    strictEqual(await res.text(), body)
+    done()
   })
 })
 
 test('fail to extract locked body', (t) => {
-  t.plan(1)
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const stream = new ReadableStream({})
   const reader = stream.getReader()
@@ -427,13 +464,13 @@ test('fail to extract locked body', (t) => {
     // eslint-disable-next-line
     new Response(stream)
   } catch (err) {
-    t.equal(err.name, 'TypeError')
+    strictEqual(err.name, 'TypeError')
   }
   reader.cancel()
 })
 
 test('fail to extract locked body', (t) => {
-  t.plan(1)
+  const { strictEqual } = tspl(t, { plan: 1 })
 
   const stream = new ReadableStream({})
   const reader = stream.getReader()
@@ -445,13 +482,13 @@ test('fail to extract locked body', (t) => {
       keepalive: true
     })
   } catch (err) {
-    t.equal(err.message, 'keepalive')
+    strictEqual(err.message, 'keepalive')
   }
   reader.cancel()
 })
 
-test('post FormData with Blob', (t) => {
-  t.plan(1)
+test('post FormData with Blob', (t, done) => {
+  const { ok } = tspl(t, { plan: 1 })
 
   const body = new FormData()
   body.append('field1', new Blob(['asd1']))
@@ -459,19 +496,20 @@ test('post FormData with Blob', (t) => {
   const server = createServer((req, res) => {
     req.pipe(res)
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`, {
       method: 'PUT',
       body
     })
-    t.ok(/asd1/.test(await res.text()))
+    ok(/asd1/.test(await res.text()))
+    done()
   })
 })
 
-test('post FormData with File', (t) => {
-  t.plan(2)
+test('post FormData with File', (t, done) => {
+  const { ok } = tspl(t, { plan: 2 })
 
   const body = new FormData()
   body.append('field1', new File(['asd1'], 'filename123'))
@@ -479,7 +517,7 @@ test('post FormData with File', (t) => {
   const server = createServer((req, res) => {
     req.pipe(res)
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const res = await fetch(`http://localhost:${server.address().port}`, {
@@ -487,29 +525,30 @@ test('post FormData with File', (t) => {
       body
     })
     const result = await res.text()
-    t.ok(/asd1/.test(result))
-    t.ok(/filename123/.test(result))
+    ok(/asd1/.test(result))
+    ok(/filename123/.test(result))
+    done()
   })
 })
 
 test('invalid url', async (t) => {
-  t.plan(1)
+  const { match } = tspl(t, { plan: 1 })
 
   try {
     await fetch('http://invalid')
   } catch (e) {
-    t.match(e.cause.message, 'invalid')
+    match(e.cause.message, /invalid/)
   }
 })
 
-test('custom agent', (t) => {
-  t.plan(2)
+test('custom agent', (t, done) => {
+  const { ok, deepStrictEqual } = tspl(t, { plan: 2 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const dispatcher = new Client('http://localhost:' + server.address().port, {
@@ -518,25 +557,25 @@ test('custom agent', (t) => {
     })
     const oldDispatch = dispatcher.dispatch
     dispatcher.dispatch = function (options, handler) {
-      t.pass('custom dispatcher')
+      ok(true)
       return oldDispatch.call(this, options, handler)
     }
-    t.teardown(server.close.bind(server))
     const body = await fetch(`http://localhost:${server.address().port}`, {
       dispatcher
     })
-    t.strictSame(obj, await body.json())
+    deepStrictEqual(obj, await body.json())
+    done()
   })
 })
 
-test('custom agent node fetch', (t) => {
-  t.plan(2)
+test('custom agent node fetch', (t, done) => {
+  const { ok, deepStrictEqual } = tspl(t, { plan: 2 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     res.end(JSON.stringify(obj))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const dispatcher = new Client('http://localhost:' + server.address().port, {
@@ -545,41 +584,42 @@ test('custom agent node fetch', (t) => {
     })
     const oldDispatch = dispatcher.dispatch
     dispatcher.dispatch = function (options, handler) {
-      t.pass('custom dispatcher')
+      ok(true)
       return oldDispatch.call(this, options, handler)
     }
-    t.teardown(server.close.bind(server))
     const body = await nodeFetch.fetch(`http://localhost:${server.address().port}`, {
       dispatcher
     })
-    t.strictSame(obj, await body.json())
+    deepStrictEqual(obj, await body.json())
+    done()
   })
 })
 
-test('error on redirect', async (t) => {
+test('error on redirect', (t, done) => {
   const server = createServer((req, res) => {
     res.statusCode = 302
     res.end()
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const errorCause = await fetch(`http://localhost:${server.address().port}`, {
       redirect: 'error'
     }).catch((e) => e.cause)
 
-    t.equal(errorCause.message, 'unexpected redirect')
+    assert.strictEqual(errorCause.message, 'unexpected redirect')
+    done()
   })
 })
 
 // https://github.com/nodejs/undici/issues/1527
 test('fetching with Request object - issue #1527', async (t) => {
   const server = createServer((req, res) => {
-    t.pass()
+    assert.ok(true)
     res.end()
   }).listen(0)
 
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
   await once(server, 'listening')
 
   const body = JSON.stringify({ foo: 'bar' })
@@ -588,17 +628,16 @@ test('fetching with Request object - issue #1527', async (t) => {
     body
   })
 
-  await t.resolves(fetch(request))
-  t.end()
+  await assert.doesNotReject(fetch(request))
 })
 
-test('do not decode redirect body', (t) => {
-  t.plan(3)
+test('do not decode redirect body', (t, done) => {
+  const { ok, strictEqual } = tspl(t, { plan: 3 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
     if (req.url === '/resource') {
-      t.pass('we redirect')
+      ok(true)
       res.statusCode = 301
       res.setHeader('location', '/resource/')
       // Some dumb http servers set the content-encoding gzip
@@ -607,34 +646,36 @@ test('do not decode redirect body', (t) => {
       res.end()
       return
     }
-    t.pass('actual response')
+    ok(true)
     res.setHeader('content-encoding', 'gzip')
     res.end(gzipSync(JSON.stringify(obj)))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const body = await fetch(`http://localhost:${server.address().port}/resource`)
-    t.strictSame(JSON.stringify(obj), await body.text())
+    strictEqual(JSON.stringify(obj), await body.text())
+    done()
   })
 })
 
-test('decode non-redirect body with location header', (t) => {
-  t.plan(2)
+test('decode non-redirect body with location header', (t, done) => {
+  const { ok, strictEqual } = tspl(t, { plan: 2 })
 
   const obj = { asd: true }
   const server = createServer((req, res) => {
-    t.pass('response')
+    ok(true)
     res.statusCode = 201
     res.setHeader('location', '/resource/')
     res.setHeader('content-encoding', 'gzip')
     res.end(gzipSync(JSON.stringify(obj)))
   })
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
 
   server.listen(0, async () => {
     const body = await fetch(`http://localhost:${server.address().port}/resource`)
-    t.strictSame(JSON.stringify(obj), await body.text())
+    strictEqual(JSON.stringify(obj), await body.text())
+    done()
   })
 })
 
@@ -655,7 +696,7 @@ test('Receiving non-Latin1 headers', async (t) => {
     res.end()
   }).listen(0)
 
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
   await once(server, 'listening')
 
   const url = `http://localhost:${server.address().port}`
@@ -665,7 +706,6 @@ test('Receiving non-Latin1 headers', async (t) => {
     .map(([, v]) => v)
   const lengths = cdHeaders.map(h => h.length)
 
-  t.same(cdHeaders, ContentDisposition)
-  t.same(lengths, [30, 34, 94, 104, 90])
-  t.end()
+  assert.deepStrictEqual(cdHeaders, ContentDisposition)
+  assert.deepStrictEqual(lengths, [30, 34, 94, 104, 90])
 })
