@@ -1,30 +1,27 @@
 'use strict'
 
-const { test } = require('tap')
+const { test } = require('node:test')
+const assert = require('node:assert')
 const {
-  File,
   FormData,
   Headers,
   Request,
   Response
 } = require('../../index')
 
-test('Symbol.toStringTag descriptor', (t) => {
+test('Symbol.toStringTag descriptor', () => {
   for (const cls of [
-    File,
     FormData,
     Headers,
     Request,
     Response
   ]) {
     const desc = Object.getOwnPropertyDescriptor(cls.prototype, Symbol.toStringTag)
-    t.same(desc, {
+    assert.deepStrictEqual(desc, {
       value: cls.name,
       writable: false,
       enumerable: false,
       configurable: true
     })
   }
-
-  t.end()
 })
