@@ -1,19 +1,20 @@
 'use strict'
 
 const { fetch } = require('../..')
-const { DOMException } = require('../../lib/fetch/constants')
-const { once } = require('events')
-const { createServer } = require('http')
-const { test } = require('tap')
+const { once } = require('node:events')
+const { createServer } = require('node:http')
+const { test } = require('node:test')
+const assert = require('node:assert')
+const { closeServerAsPromise } = require('../utils/node-http')
 
 test('error reason is forwarded - issue #2171', { skip: !AbortSignal.timeout }, async (t) => {
   const server = createServer(() => {}).listen(0)
 
-  t.teardown(server.close.bind(server))
+  t.after(closeServerAsPromise(server))
   await once(server, 'listening')
 
   const timeout = AbortSignal.timeout(100)
-  await t.rejects(
+  await assert.rejects(
     fetch(`http://localhost:${server.address().port}`, {
       signal: timeout
     }),
