@@ -1,25 +1,108 @@
 'use strict'
 
-const { test, teardown } = require('tap')
+const { tspl } = require('@matteo.collina/tspl')
+const { test, after } = require('node:test')
 const { request, fetch, setGlobalDispatcher, getGlobalDispatcher } = require('..')
-const { InvalidArgumentError } = require('../lib/core/errors')
-const { nodeMajor } = require('../lib/core/util')
-const { readFileSync } = require('fs')
-const { join } = require('path')
-const ProxyAgent = require('../lib/proxy-agent')
-const Pool = require('../lib/pool')
-const { createServer } = require('http')
-const https = require('https')
-const proxy = require('proxy')
+const { InvalidArgumentError, SecureProxyConnectionError } = require('../lib/core/errors')
+const ProxyAgent = require('../lib/dispatcher/proxy-agent')
+const Pool = require('../lib/dispatcher/pool')
+const { createServer } = require('node:http')
+const https = require('node:https')
+const { createProxy } = require('proxy')
+
+const certs = (() => {
+  const forge = require('node-forge')
+  const createCert = (cn, issuer, keyLength = 2048) => {
+    const keys = forge.pki.rsa.generateKeyPair(keyLength)
+    const cert = forge.pki.createCertificate()
+    cert.publicKey = keys.publicKey
+    cert.serialNumber = '' + Date.now()
+    cert.validity.notBefore = new Date()
+    cert.validity.notAfter = new Date()
+    cert.validity.notAfter.setFullYear(cert.validity.notBefore.getFullYear() + 10)
+
+    const attrs = [{
+      name: 'commonName',
+      value: cn
+    }]
+    cert.setSubject(attrs)
+    const isCa = issuer === undefined
+    cert.setExtensions([{
+      name: 'basicConstraints',
+      cA: isCa
+    }, {
+      name: 'keyUsage',
+      keyCertSign: true,
+      digitalSignature: true,
+      nonRepudiation: true,
+      keyEncipherment: true,
+      dataEncipherment: true
+    }, {
+      name: 'extKeyUsage',
+      serverAuth: true,
+      clientAuth: true,
+      codeSigning: true,
+      emailProtection: true,
+      timeStamping: true
+    }, {
+      name: 'nsCertType',
+      client: true,
+      server: true,
+      email: true,
+      objsign: true,
+      sslCA: isCa,
+      emailCA: isCa,
+      objCA: isCa
+    }])
+
+    const alg = forge.md.sha256.create()
+    if (issuer !== undefined) {
+      cert.setIssuer(issuer.certificate.subject.attributes)
+      cert.sign(issuer.privateKey, alg)
+    } else {
+      cert.setIssuer(attrs)
+      cert.sign(keys.privateKey, alg)
+    }
+    return {
+      privateKey: keys.privateKey,
+      publicKey: keys.publicKey,
+      certificate: cert
+    }
+  }
+
+  const root = createCert('CA')
+  const server = createCert('agent1', root)
+  const client = createCert('client', root)
+  const proxy = createCert('proxy', root)
+
+  return {
+    root: {
+      key: forge.pki.privateKeyToPem(root.privateKey),
+      crt: forge.pki.certificateToPem(root.certificate)
+    },
+    server: {
+      key: forge.pki.privateKeyToPem(server.privateKey),
+      crt: forge.pki.certificateToPem(server.certificate)
+    },
+    client: {
+      key: forge.pki.privateKeyToPem(client.privateKey),
+      crt: forge.pki.certificateToPem(client.certificate)
+    },
+    proxy: {
+      key: forge.pki.privateKeyToPem(proxy.privateKey),
+      crt: forge.pki.certificateToPem(proxy.certificate)
+    }
+  }
+})()
 
 test('should throw error when no uri is provided', (t) => {
-  t.plan(2)
+  t = tspl(t, { plan: 2 })
   t.throws(() => new ProxyAgent(), InvalidArgumentError)
   t.throws(() => new ProxyAgent({}), InvalidArgumentError)
 })
 
 test('using auth in combination with token should throw', (t) => {
-  t.plan(1)
+  t = tspl(t, { plan: 1 })
   t.throws(() => new ProxyAgent({
     auth: 'foo',
     token: 'Bearer bar',
@@ -29,14 +112,15 @@ test('using auth in combination with token should throw', (t) => {
   )
 })
 
-test('should accept string and object as options', (t) => {
-  t.plan(2)
+test('should accept string, URL and object as options', (t) => {
+  t = tspl(t, { plan: 3 })
   t.doesNotThrow(() => new ProxyAgent('http://example.com'))
+  t.doesNotThrow(() => new ProxyAgent(new URL('http://example.com')))
   t.doesNotThrow(() => new ProxyAgent({ uri: 'http://example.com' }))
 })
 
 test('use proxy-agent to connect through proxy', async (t) => {
-  t.plan(6)
+  t = tspl(t, { plan: 6 })
   const server = await buildServer()
   const proxy = await buildProxy()
   delete proxy.authenticate
@@ -47,12 +131,12 @@ test('use proxy-agent to connect through proxy', async (t) => {
   const parsedOrigin = new URL(serverUrl)
 
   proxy.on('connect', () => {
-    t.pass('should connect to proxy')
+    t.ok(true, 'should connect to proxy')
   })
 
   server.on('request', (req, res) => {
-    t.equal(req.url, '/')
-    t.equal(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    t.strictEqual(req.url, '/')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ hello: 'world' }))
   })
@@ -64,9 +148,9 @@ test('use proxy-agent to connect through proxy', async (t) => {
   } = await request(serverUrl, { dispatcher: proxyAgent })
   const json = await body.json()
 
-  t.equal(statusCode, 200)
-  t.same(json, { hello: 'world' })
-  t.equal(headers.connection, 'keep-alive', 'should remain the connection open')
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
 
   server.close()
   proxy.close()
@@ -74,22 +158,22 @@ test('use proxy-agent to connect through proxy', async (t) => {
 })
 
 test('use proxy agent to connect through proxy using Pool', async (t) => {
-  t.plan(3)
+  t = tspl(t, { plan: 3 })
   const server = await buildServer()
   const proxy = await buildProxy()
   let resolveFirstConnect
   let connectCount = 0
 
-  proxy.authenticate = async function (req, fn) {
+  proxy.authenticate = async function (req) {
     if (++connectCount === 2) {
-      t.pass('second connect should arrive while first is still inflight')
+      t.ok(true, 'second connect should arrive while first is still inflight')
       resolveFirstConnect()
-      fn(null, true)
+      return true
     } else {
       await new Promise((resolve) => {
         resolveFirstConnect = resolve
       })
-      fn(null, true)
+      return true
     }
   }
 
@@ -105,15 +189,15 @@ test('use proxy agent to connect through proxy using Pool', async (t) => {
   const proxyAgent = new ProxyAgent({ auth: Buffer.from('user:pass').toString('base64'), uri: proxyUrl, clientFactory })
   const firstRequest = request(`${serverUrl}`, { dispatcher: proxyAgent })
   const secondRequest = await request(`${serverUrl}`, { dispatcher: proxyAgent })
-  t.equal((await firstRequest).statusCode, 200)
-  t.equal(secondRequest.statusCode, 200)
+  t.strictEqual((await firstRequest).statusCode, 200)
+  t.strictEqual(secondRequest.statusCode, 200)
   server.close()
   proxy.close()
   proxyAgent.close()
 })
 
 test('use proxy-agent to connect through proxy using path with params', async (t) => {
-  t.plan(6)
+  t = tspl(t, { plan: 6 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -123,11 +207,11 @@ test('use proxy-agent to connect through proxy using path with params', async (t
   const parsedOrigin = new URL(serverUrl)
 
   proxy.on('connect', () => {
-    t.pass('should call proxy')
+    t.ok(true, 'should call proxy')
   })
   server.on('request', (req, res) => {
-    t.equal(req.url, '/hello?foo=bar')
-    t.equal(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    t.strictEqual(req.url, '/hello?foo=bar')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ hello: 'world' }))
   })
@@ -139,9 +223,50 @@ test('use proxy-agent to connect through proxy using path with params', async (t
   } = await request(serverUrl + '/hello?foo=bar', { dispatcher: proxyAgent })
   const json = await body.json()
 
-  t.equal(statusCode, 200)
-  t.same(json, { hello: 'world' })
-  t.equal(headers.connection, 'keep-alive', 'should remain the connection open')
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
+
+  server.close()
+  proxy.close()
+  proxyAgent.close()
+})
+
+test('use proxy-agent to connect through proxy with basic auth in URL', async (t) => {
+  t = tspl(t, { plan: 7 })
+  const server = await buildServer()
+  const proxy = await buildProxy()
+
+  const serverUrl = `http://localhost:${server.address().port}`
+  const proxyUrl = new URL(`http://user:pass@localhost:${proxy.address().port}`)
+  const proxyAgent = new ProxyAgent(proxyUrl)
+  const parsedOrigin = new URL(serverUrl)
+
+  proxy.authenticate = function (req, fn) {
+    t.ok(true, 'authentication should be called')
+    return req.headers['proxy-authorization'] === `Basic ${Buffer.from('user:pass').toString('base64')}`
+  }
+  proxy.on('connect', () => {
+    t.ok(true, 'proxy should be called')
+  })
+
+  server.on('request', (req, res) => {
+    t.strictEqual(req.url, '/hello?foo=bar')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    res.setHeader('content-type', 'application/json')
+    res.end(JSON.stringify({ hello: 'world' }))
+  })
+
+  const {
+    statusCode,
+    headers,
+    body
+  } = await request(serverUrl + '/hello?foo=bar', { dispatcher: proxyAgent })
+  const json = await body.json()
+
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
 
   server.close()
   proxy.close()
@@ -149,7 +274,7 @@ test('use proxy-agent to connect through proxy using path with params', async (t
 })
 
 test('use proxy-agent with auth', async (t) => {
-  t.plan(7)
+  t = tspl(t, { plan: 7 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -161,17 +286,17 @@ test('use proxy-agent with auth', async (t) => {
   })
   const parsedOrigin = new URL(serverUrl)
 
-  proxy.authenticate = function (req, fn) {
-    t.pass('authentication should be called')
-    fn(null, req.headers['proxy-authorization'] === `Basic ${Buffer.from('user:pass').toString('base64')}`)
+  proxy.authenticate = function (req) {
+    t.ok(true, 'authentication should be called')
+    return req.headers['proxy-authorization'] === `Basic ${Buffer.from('user:pass').toString('base64')}`
   }
   proxy.on('connect', () => {
-    t.pass('proxy should be called')
+    t.ok(true, 'proxy should be called')
   })
 
   server.on('request', (req, res) => {
-    t.equal(req.url, '/hello?foo=bar')
-    t.equal(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    t.strictEqual(req.url, '/hello?foo=bar')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ hello: 'world' }))
   })
@@ -183,9 +308,9 @@ test('use proxy-agent with auth', async (t) => {
   } = await request(serverUrl + '/hello?foo=bar', { dispatcher: proxyAgent })
   const json = await body.json()
 
-  t.equal(statusCode, 200)
-  t.same(json, { hello: 'world' })
-  t.equal(headers.connection, 'keep-alive', 'should remain the connection open')
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
 
   server.close()
   proxy.close()
@@ -193,7 +318,7 @@ test('use proxy-agent with auth', async (t) => {
 })
 
 test('use proxy-agent with token', async (t) => {
-  t.plan(7)
+  t = tspl(t, { plan: 7 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -205,17 +330,17 @@ test('use proxy-agent with token', async (t) => {
   })
   const parsedOrigin = new URL(serverUrl)
 
-  proxy.authenticate = function (req, fn) {
-    t.pass('authentication should be called')
-    fn(null, req.headers['proxy-authorization'] === `Bearer ${Buffer.from('user:pass').toString('base64')}`)
+  proxy.authenticate = function (req) {
+    t.ok(true, 'authentication should be called')
+    return req.headers['proxy-authorization'] === `Bearer ${Buffer.from('user:pass').toString('base64')}`
   }
   proxy.on('connect', () => {
-    t.pass('proxy should be called')
+    t.ok(true, 'proxy should be called')
   })
 
   server.on('request', (req, res) => {
-    t.equal(req.url, '/hello?foo=bar')
-    t.equal(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    t.strictEqual(req.url, '/hello?foo=bar')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ hello: 'world' }))
   })
@@ -227,9 +352,9 @@ test('use proxy-agent with token', async (t) => {
   } = await request(serverUrl + '/hello?foo=bar', { dispatcher: proxyAgent })
   const json = await body.json()
 
-  t.equal(statusCode, 200)
-  t.same(json, { hello: 'world' })
-  t.equal(headers.connection, 'keep-alive', 'should remain the connection open')
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
 
   server.close()
   proxy.close()
@@ -237,7 +362,7 @@ test('use proxy-agent with token', async (t) => {
 })
 
 test('use proxy-agent with custom headers', async (t) => {
-  t.plan(2)
+  t = tspl(t, { plan: 2 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -251,11 +376,11 @@ test('use proxy-agent with custom headers', async (t) => {
   })
 
   proxy.on('connect', (req) => {
-    t.equal(req.headers['user-agent'], 'Foobar/1.0.0')
+    t.strictEqual(req.headers['user-agent'], 'Foobar/1.0.0')
   })
 
   server.on('request', (req, res) => {
-    t.equal(req.headers['user-agent'], 'BarBaz/1.0.0')
+    t.strictEqual(req.headers['user-agent'], 'BarBaz/1.0.0')
     res.end()
   })
 
@@ -270,7 +395,7 @@ test('use proxy-agent with custom headers', async (t) => {
 })
 
 test('sending proxy-authorization in request headers should throw', async (t) => {
-  t.plan(3)
+  t = tspl(t, { plan: 3 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -327,7 +452,7 @@ test('sending proxy-authorization in request headers should throw', async (t) =>
 })
 
 test('use proxy-agent with setGlobalDispatcher', async (t) => {
-  t.plan(6)
+  t = tspl(t, { plan: 6 })
   const defaultDispatcher = getGlobalDispatcher()
 
   const server = await buildServer()
@@ -339,14 +464,14 @@ test('use proxy-agent with setGlobalDispatcher', async (t) => {
   const parsedOrigin = new URL(serverUrl)
   setGlobalDispatcher(proxyAgent)
 
-  t.teardown(() => setGlobalDispatcher(defaultDispatcher))
+  after(() => setGlobalDispatcher(defaultDispatcher))
 
   proxy.on('connect', () => {
-    t.pass('should call proxy')
+    t.ok(true, 'should call proxy')
   })
   server.on('request', (req, res) => {
-    t.equal(req.url, '/hello?foo=bar')
-    t.equal(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
+    t.strictEqual(req.url, '/hello?foo=bar')
+    t.strictEqual(req.headers.host, parsedOrigin.host, 'should not use proxyUrl as host')
     res.setHeader('content-type', 'application/json')
     res.end(JSON.stringify({ hello: 'world' }))
   })
@@ -358,17 +483,17 @@ test('use proxy-agent with setGlobalDispatcher', async (t) => {
   } = await request(serverUrl + '/hello?foo=bar')
   const json = await body.json()
 
-  t.equal(statusCode, 200)
-  t.same(json, { hello: 'world' })
-  t.equal(headers.connection, 'keep-alive', 'should remain the connection open')
+  t.strictEqual(statusCode, 200)
+  t.deepStrictEqual(json, { hello: 'world' })
+  t.strictEqual(headers.connection, 'keep-alive', 'should remain the connection open')
 
   server.close()
   proxy.close()
   proxyAgent.close()
 })
 
-test('ProxyAgent correctly sends headers when using fetch - #1355, #1623', { skip: nodeMajor < 16 }, async (t) => {
-  t.plan(2)
+test('ProxyAgent correctly sends headers when using fetch - #1355, #1623', async (t) => {
+  t = tspl(t, { plan: 2 })
   const defaultDispatcher = getGlobalDispatcher()
 
   const server = await buildServer()
@@ -380,7 +505,7 @@ test('ProxyAgent correctly sends headers when using fetch - #1355, #1623', { ski
   const proxyAgent = new ProxyAgent(proxyUrl)
   setGlobalDispatcher(proxyAgent)
 
-  t.teardown(() => setGlobalDispatcher(defaultDispatcher))
+  after(() => setGlobalDispatcher(defaultDispatcher))
 
   const expectedHeaders = {
     host: `localhost:${server.address().port}`,
@@ -394,16 +519,16 @@ test('ProxyAgent correctly sends headers when using fetch - #1355, #1623', { ski
   }
 
   const expectedProxyHeaders = {
-    host: `localhost:${proxy.address().port}`,
+    host: `localhost:${server.address().port}`,
     connection: 'close'
   }
 
   proxy.on('connect', (req, res) => {
-    t.same(req.headers, expectedProxyHeaders)
+    t.deepStrictEqual(req.headers, expectedProxyHeaders)
   })
 
   server.on('request', (req, res) => {
-    t.same(req.headers, expectedHeaders)
+    t.deepStrictEqual(req.headers, expectedHeaders)
     res.end('goodbye')
   })
 
@@ -418,14 +543,17 @@ test('ProxyAgent correctly sends headers when using fetch - #1355, #1623', { ski
 })
 
 test('should throw when proxy does not return 200', async (t) => {
+  t = tspl(t, { plan: 3 })
+
   const server = await buildServer()
   const proxy = await buildProxy()
 
   const serverUrl = `http://localhost:${server.address().port}`
   const proxyUrl = `http://localhost:${proxy.address().port}`
 
-  proxy.authenticate = function (req, fn) {
-    fn(null, false)
+  proxy.authenticate = function (_req) {
+    t.ok(true, 'should call authenticate')
+    return false
   }
 
   const proxyAgent = new ProxyAgent(proxyUrl)
@@ -433,42 +561,45 @@ test('should throw when proxy does not return 200', async (t) => {
     await request(serverUrl, { dispatcher: proxyAgent })
     t.fail()
   } catch (e) {
-    t.pass()
+    t.ok(true, 'pass')
     t.ok(e)
   }
 
   server.close()
   proxy.close()
   proxyAgent.close()
-  t.end()
+  await t.completed
 })
 
-test('pass ProxyAgent proxy status code error when using fetch - #2161', { skip: nodeMajor < 16 }, async (t) => {
+test('pass ProxyAgent proxy status code error when using fetch - #2161', async (t) => {
+  t = tspl(t, { plan: 2 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
   const serverUrl = `http://localhost:${server.address().port}`
   const proxyUrl = `http://localhost:${proxy.address().port}`
 
-  proxy.authenticate = function (req, fn) {
-    fn(null, false)
+  proxy.authenticate = function (_req) {
+    t.ok(true, 'should call authenticate')
+    return false
   }
 
   const proxyAgent = new ProxyAgent(proxyUrl)
   try {
     await fetch(serverUrl, { dispatcher: proxyAgent })
   } catch (e) {
-    t.hasProp(e, 'cause')
+    t.ok('cause' in e)
   }
 
   server.close()
   proxy.close()
   proxyAgent.close()
-  t.end()
+
+  await t.completed
 })
 
 test('Proxy via HTTP to HTTPS endpoint', async (t) => {
-  t.plan(4)
+  t = tspl(t, { plan: 4 })
 
   const server = await buildSSLServer()
   const proxy = await buildProxy()
@@ -479,10 +610,8 @@ test('Proxy via HTTP to HTTPS endpoint', async (t) => {
     uri: proxyUrl,
     requestTls: {
       ca: [
-        readFileSync(join(__dirname, 'fixtures', 'ca.pem'), 'utf8')
+        certs.root.crt
       ],
-      key: readFileSync(join(__dirname, 'fixtures', 'client-key-2048.pem'), 'utf8'),
-      cert: readFileSync(join(__dirname, 'fixtures', 'client-crt-2048.pem'), 'utf8'),
       servername: 'agent1'
     }
   })
@@ -493,7 +622,7 @@ test('Proxy via HTTP to HTTPS endpoint', async (t) => {
   })
 
   server.on('secureConnection', () => {
-    t.pass('server should be connected secured')
+    t.ok(true, 'server should be connected secured')
   })
 
   proxy.on('secureConnection', () => {
@@ -501,7 +630,7 @@ test('Proxy via HTTP to HTTPS endpoint', async (t) => {
   })
 
   proxy.on('connect', function () {
-    t.pass('proxy should be connected')
+    t.ok(true, 'proxy should be connected')
   })
 
   proxy.on('request', function () {
@@ -510,7 +639,7 @@ test('Proxy via HTTP to HTTPS endpoint', async (t) => {
 
   const data = await request(serverUrl, { dispatcher: proxyAgent })
   const json = await data.body.json()
-  t.strictSame(json, {
+  t.deepStrictEqual(json, {
     host: `localhost:${server.address().port}`,
     connection: 'keep-alive'
   })
@@ -521,7 +650,7 @@ test('Proxy via HTTP to HTTPS endpoint', async (t) => {
 })
 
 test('Proxy via HTTPS to HTTPS endpoint', async (t) => {
-  t.plan(5)
+  t = tspl(t, { plan: 5 })
   const server = await buildSSLServer()
   const proxy = await buildSSLProxy()
 
@@ -531,19 +660,14 @@ test('Proxy via HTTPS to HTTPS endpoint', async (t) => {
     uri: proxyUrl,
     proxyTls: {
       ca: [
-        readFileSync(join(__dirname, 'fixtures', 'ca.pem'), 'utf8')
+        certs.root.crt
       ],
-      key: readFileSync(join(__dirname, 'fixtures', 'client-key-2048.pem'), 'utf8'),
-      cert: readFileSync(join(__dirname, 'fixtures', 'client-crt-2048.pem'), 'utf8'),
-      servername: 'agent1',
-      rejectUnauthorized: false
+      servername: 'proxy'
     },
     requestTls: {
       ca: [
-        readFileSync(join(__dirname, 'fixtures', 'ca.pem'), 'utf8')
+        certs.root.crt
       ],
-      key: readFileSync(join(__dirname, 'fixtures', 'client-key-2048.pem'), 'utf8'),
-      cert: readFileSync(join(__dirname, 'fixtures', 'client-crt-2048.pem'), 'utf8'),
       servername: 'agent1'
     }
   })
@@ -554,15 +678,15 @@ test('Proxy via HTTPS to HTTPS endpoint', async (t) => {
   })
 
   server.on('secureConnection', () => {
-    t.pass('server should be connected secured')
+    t.ok(true, 'server should be connected secured')
   })
 
   proxy.on('secureConnection', () => {
-    t.pass('proxy over http should call secureConnection')
+    t.ok(true, 'proxy over http should call secureConnection')
   })
 
   proxy.on('connect', function () {
-    t.pass('proxy should be connected')
+    t.ok(true, 'proxy should be connected')
   })
 
   proxy.on('request', function () {
@@ -571,7 +695,7 @@ test('Proxy via HTTPS to HTTPS endpoint', async (t) => {
 
   const data = await request(serverUrl, { dispatcher: proxyAgent })
   const json = await data.body.json()
-  t.strictSame(json, {
+  t.deepStrictEqual(json, {
     host: `localhost:${server.address().port}`,
     connection: 'keep-alive'
   })
@@ -582,7 +706,7 @@ test('Proxy via HTTPS to HTTPS endpoint', async (t) => {
 })
 
 test('Proxy via HTTPS to HTTP endpoint', async (t) => {
-  t.plan(3)
+  t = tspl(t, { plan: 3 })
   const server = await buildServer()
   const proxy = await buildSSLProxy()
 
@@ -592,12 +716,9 @@ test('Proxy via HTTPS to HTTP endpoint', async (t) => {
     uri: proxyUrl,
     proxyTls: {
       ca: [
-        readFileSync(join(__dirname, 'fixtures', 'ca.pem'), 'utf8')
+        certs.root.crt
       ],
-      key: readFileSync(join(__dirname, 'fixtures', 'client-key-2048.pem'), 'utf8'),
-      cert: readFileSync(join(__dirname, 'fixtures', 'client-crt-2048.pem'), 'utf8'),
-      servername: 'agent1',
-      rejectUnauthorized: false
+      servername: 'proxy'
     }
   })
 
@@ -611,7 +732,7 @@ test('Proxy via HTTPS to HTTP endpoint', async (t) => {
   })
 
   proxy.on('secureConnection', () => {
-    t.pass('proxy over http should call secureConnection')
+    t.ok(true, 'proxy over http should call secureConnection')
   })
 
   proxy.on('request', function () {
@@ -620,7 +741,7 @@ test('Proxy via HTTPS to HTTP endpoint', async (t) => {
 
   const data = await request(serverUrl, { dispatcher: proxyAgent })
   const json = await data.body.json()
-  t.strictSame(json, {
+  t.deepStrictEqual(json, {
     host: `localhost:${server.address().port}`,
     connection: 'keep-alive'
   })
@@ -631,7 +752,7 @@ test('Proxy via HTTPS to HTTP endpoint', async (t) => {
 })
 
 test('Proxy via HTTP to HTTP endpoint', async (t) => {
-  t.plan(3)
+  t = tspl(t, { plan: 3 })
   const server = await buildServer()
   const proxy = await buildProxy()
 
@@ -653,7 +774,7 @@ test('Proxy via HTTP to HTTP endpoint', async (t) => {
   })
 
   proxy.on('connect', () => {
-    t.pass('connect to proxy')
+    t.ok(true, 'connect to proxy')
   })
 
   proxy.on('request', function () {
@@ -662,7 +783,7 @@ test('Proxy via HTTP to HTTP endpoint', async (t) => {
 
   const data = await request(serverUrl, { dispatcher: proxyAgent })
   const json = await data.body.json()
-  t.strictSame(json, {
+  t.deepStrictEqual(json, {
     host: `localhost:${server.address().port}`,
     connection: 'keep-alive'
   })
@@ -672,6 +793,86 @@ test('Proxy via HTTP to HTTP endpoint', async (t) => {
   proxyAgent.close()
 })
 
+test('Proxy via HTTPS to HTTP fails on wrong SNI', async (t) => {
+  t = tspl(t, { plan: 3 })
+  const server = await buildServer()
+  const proxy = await buildSSLProxy()
+
+  const serverUrl = `http://localhost:${server.address().port}`
+  const proxyUrl = `https://localhost:${proxy.address().port}`
+  const proxyAgent = new ProxyAgent({
+    uri: proxyUrl,
+    proxyTls: {
+      ca: [
+        certs.root.crt
+      ]
+    }
+  })
+
+  server.on('request', function (req, res) {
+    t.ok(!req.connection.encrypted)
+    res.end(JSON.stringify(req.headers))
+  })
+
+  server.on('secureConnection', () => {
+    t.fail('server is http')
+  })
+
+  proxy.on('secureConnection', () => {
+    t.fail('proxy is http')
+  })
+
+  proxy.on('connect', () => {
+    t.ok(true, 'connect to proxy')
+  })
+
+  proxy.on('request', function () {
+    t.fail('proxy should never receive requests')
+  })
+
+  try {
+    await request(serverUrl, { dispatcher: proxyAgent })
+    throw new Error('should fail')
+  } catch (e) {
+    t.ok(e instanceof SecureProxyConnectionError)
+    t.ok(e.cause instanceof Error)
+    t.ok(e.cause.code === 'ERR_TLS_CERT_ALTNAME_INVALID')
+  }
+
+  server.close()
+  proxy.close()
+  proxyAgent.close()
+})
+
+test('ProxyAgent keeps customized host in request headers - #3019', async (t) => {
+  t = tspl(t, { plan: 2 })
+  const server = await buildServer()
+  const proxy = await buildProxy()
+
+  const serverUrl = `http://localhost:${server.address().port}`
+  const proxyUrl = `http://localhost:${proxy.address().port}`
+  const proxyAgent = new ProxyAgent(proxyUrl)
+  const customHost = 'example.com'
+
+  proxy.on('connect', (req) => {
+    t.strictEqual(req.headers.host, `localhost:${server.address().port}`)
+  })
+
+  server.on('request', (req, res) => {
+    t.strictEqual(req.headers.host, customHost)
+    res.end()
+  })
+
+  await request(serverUrl, {
+    headers: { Host: customHost },
+    dispatcher: proxyAgent
+  })
+
+  server.close()
+  proxy.close()
+  proxyAgent.close()
+})
+
 function buildServer () {
   return new Promise((resolve) => {
     const server = createServer()
@@ -682,10 +883,10 @@ function buildServer () {
 function buildSSLServer () {
   const serverOptions = {
     ca: [
-      readFileSync(join(__dirname, 'fixtures', 'client-ca-crt.pem'), 'utf8')
+      certs.root.crt
     ],
-    key: readFileSync(join(__dirname, 'fixtures', 'key.pem'), 'utf8'),
-    cert: readFileSync(join(__dirname, 'fixtures', 'cert.pem'), 'utf8')
+    key: certs.server.key,
+    cert: certs.server.crt
   }
   return new Promise((resolve) => {
     const server = https.createServer(serverOptions)
@@ -696,8 +897,8 @@ function buildSSLServer () {
 function buildProxy (listener) {
   return new Promise((resolve) => {
     const server = listener
-      ? proxy(createServer(listener))
-      : proxy(createServer())
+      ? createProxy(createServer(listener))
+      : createProxy(createServer())
     server.listen(0, () => resolve(server))
   })
 }
@@ -705,16 +906,14 @@ function buildProxy (listener) {
 function buildSSLProxy () {
   const serverOptions = {
     ca: [
-      readFileSync(join(__dirname, 'fixtures', 'client-ca-crt.pem'), 'utf8')
+      certs.root.crt
     ],
-    key: readFileSync(join(__dirname, 'fixtures', 'key.pem'), 'utf8'),
-    cert: readFileSync(join(__dirname, 'fixtures', 'cert.pem'), 'utf8')
+    key: certs.proxy.key,
+    cert: certs.proxy.crt
   }
 
   return new Promise((resolve) => {
-    const server = proxy(https.createServer(serverOptions))
+    const server = createProxy(https.createServer(serverOptions))
     server.listen(0, () => resolve(server))
   })
 }
-
-teardown(() => process.exit())
