@@ -1,7 +1,7 @@
 import { expectAssignable } from 'tsd'
 import { errors } from '../..'
 import Client from '../../types/client'
-import { IncomingHttpHeaders } from "../../types/header";
+import { IncomingHttpHeaders } from '../../types/header'
 
 expectAssignable<errors.UndiciError>(new errors.UndiciError())
 expectAssignable<string>(new errors.UndiciError().name)
@@ -27,6 +27,14 @@ expectAssignable<errors.BodyTimeoutError>(new errors.BodyTimeoutError())
 expectAssignable<'BodyTimeoutError'>(new errors.BodyTimeoutError().name)
 expectAssignable<'UND_ERR_BODY_TIMEOUT'>(new errors.BodyTimeoutError().code)
 
+expectAssignable<errors.UndiciError>(new errors.ResponseError('', 0, {}))
+expectAssignable<errors.ResponseError>(new errors.ResponseError('', 0, {}))
+expectAssignable<'ResponseError'>(new errors.ResponseError('', 0, {}).name)
+expectAssignable<'UND_ERR_RESPONSE'>(new errors.ResponseError('', 0, {}).code)
+expectAssignable<number>(new errors.ResponseError('', 0, {}).statusCode)
+expectAssignable<IncomingHttpHeaders | string[] | null>(new errors.ResponseError('', 0, {}).headers)
+expectAssignable<null | Record<string, any> | string>(new errors.ResponseError('', 0, {}).body)
+
 expectAssignable<errors.UndiciError>(new errors.ResponseStatusCodeError())
 expectAssignable<errors.ResponseStatusCodeError>(new errors.ResponseStatusCodeError())
 expectAssignable<'ResponseStatusCodeError'>(new errors.ResponseStatusCodeError().name)
@@ -101,9 +109,19 @@ expectAssignable<errors.ResponseExceededMaxSizeError>(new errors.ResponseExceede
 expectAssignable<'ResponseExceededMaxSizeError'>(new errors.ResponseExceededMaxSizeError().name)
 expectAssignable<'UND_ERR_RES_EXCEEDED_MAX_SIZE'>(new errors.ResponseExceededMaxSizeError().code)
 
+expectAssignable<errors.UndiciError>(new errors.RequestRetryError('', 0))
+expectAssignable<errors.RequestRetryError>(new errors.RequestRetryError('', 0))
+expectAssignable<'RequestRetryError'>(new errors.RequestRetryError('', 0).name)
+expectAssignable<'UND_ERR_REQ_RETRY'>(new errors.RequestRetryError('', 0).code)
+
+expectAssignable<errors.UndiciError>(new errors.SecureProxyConnectionError())
+expectAssignable<errors.SecureProxyConnectionError>(new errors.SecureProxyConnectionError())
+expectAssignable<'SecureProxyConnectionError'>(new errors.SecureProxyConnectionError().name)
+expectAssignable<'UND_ERR_PRX_TLS'>(new errors.SecureProxyConnectionError().code)
+
 {
   // @ts-ignore
-  function f (): errors.HeadersTimeoutError | errors.ConnectTimeoutError { return }
+  function f (): errors.HeadersTimeoutError | errors.ConnectTimeoutError { }
 
   const e = f()
 
