@@ -1,10 +1,11 @@
 'use strict'
 
-const { test } = require('tap')
+const { test } = require('node:test')
+const assert = require('node:assert')
 const { WebSocket } = require('../..')
 
-test('Constructor', (t) => {
-  t.throws(
+test('Constructor', () => {
+  assert.throws(
     () => new WebSocket('abc'),
     {
       name: 'SyntaxError',
@@ -12,7 +13,7 @@ test('Constructor', (t) => {
     }
   )
 
-  t.throws(
+  assert.throws(
     () => new WebSocket('wss://echo.websocket.events/#a'),
     {
       name: 'SyntaxError',
@@ -20,7 +21,7 @@ test('Constructor', (t) => {
     }
   )
 
-  t.throws(
+  assert.throws(
     () => new WebSocket('wss://echo.websocket.events', ''),
     {
       name: 'SyntaxError',
@@ -28,7 +29,7 @@ test('Constructor', (t) => {
     }
   )
 
-  t.throws(
+  assert.throws(
     () => new WebSocket('wss://echo.websocket.events', ['chat', 'chat']),
     {
       name: 'SyntaxError',
@@ -36,13 +37,11 @@ test('Constructor', (t) => {
     }
   )
 
-  t.throws(
+  assert.throws(
     () => new WebSocket('wss://echo.websocket.events', ['<>@,;:\\"/[]?={}\t']),
     {
       name: 'SyntaxError',
       constructor: DOMException
     }
   )
-
-  t.end()
 })
